# 100x Python Client

This is a Python client for the 100x API. It is a simple wrapper around the API, and provides a convenient way to interact with the API from Python.

## Installation
```bash
pip install hundred-x
```